<?php
	
	/*
	WPAS File Manager v1.0
    Copyright (C) 2009 Kirill Bugvin
	
	This file is part of WPAS File Manager.
	
    WPAS File Manager is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    WPAS File Manager is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	Kirill Bugvin
	kirill@bugvin.ee
	
	Bugvin Web Development OU
	http://www.bugvin.ee/
	Tallinn, Estonia
	*/

	function realURL($url){
		
		$url = explode('/', $url);
		
		foreach($url as $key => $val){
			$val = trim($val);
			
			if($val=='..'){unset($url[$key-1]);}
			if(!$val or $val=='.' or $val=='..'){unset($url[$key]);}
		}
		
		return implode('/', $url);
		
	}

	function sizeMarker($filesize){
		
		if($filesize>=1024*1024*1024){$size = round($filesize/1024/1024/1024, 2).' Gb';}elseif
			($filesize>=1024*1024){$size = round($filesize/1024/1024, 2).' Mb';}elseif
				($filesize>=1024){$size = round($filesize/1024, 2).' Kb';}elseif
					($filesize>=1){$size = $filesize.' b';}else{$size = '0 b';}
		
		return $size;
		
	}
	
	function dirSize($folder){
		
		$size = 0;
		
		if(function_exists('exec')){
			$tmp = explode("\t", exec('du '.$folder), 2);
		}
		
		if($tmp && trim($tmp[0])){
			
			$size = $tmp[0];
			
		}else if(is_dir($folder) && ($dir = @opendir($folder))){
			
			while(false !== ($file = readdir($dir))){
				if($file!='.' && $file!='..'){
					
					if(is_dir($folder.'/'.$file)){
						$size += dirSize($folder.'/'.$file);
					}else{
						$size += filesize($folder.'/'.$file);
					}
					
				}
			}
			
		}
		
		return $size;
		
	}
	
	function translitFileName($file_name){
		
		$w = array();
		
		$w['а'] = 'a';	$w['б'] = 'b';
		$w['в'] = 'v';	$w['г'] = 'g';
		$w['д'] = 'd';	$w['е'] = 'e';
		$w['ё'] = 'e';	$w['ж'] = 'z';
		$w['з'] = 'z';	$w['и'] = 'i';
		$w['й'] = 'j';	$w['к'] = 'k';
		$w['л'] = 'l';	$w['м'] = 'm';
		$w['н'] = 'n';	$w['о'] = 'o';
		$w['п'] = 'p';	$w['р'] = 'r';
		$w['с'] = 's';	$w['т'] = 't';
		$w['у'] = 'u';	$w['ф'] = 'f';
		$w['х'] = 'h';	$w['ц'] = 'ts';
		$w['ч'] = 'ts';	$w['ш'] = 'sh';
		$w['щ'] = 'sh';	$w['ь'] = '';
		$w['ъ'] = '';	$w['ы'] = 'i';
		$w['э'] = 'e';	$w['ю'] = 'ju';
		$w['я'] = 'ja';
		
		foreach($w as $key => $val){$w[mb_strtoupper($key)] = mb_strtoupper($val);}
		
		return strtr($file_name, $w);
		
	}
	
	
	function cleanFileName($file_name){
		
		$file_name = translitFileName($file_name);
		$file_name = preg_replace('/[^a-zA-Z0-9s.'.quotemeta('()!@$&_+=~\{\}[],.').']/', ' ', $file_name);
		
		$file_name = preg_replace('/[\s]+/', ' ', $file_name);
		$file_name = str_replace(' ', '_', trim($file_name));
		
		return $file_name;
		
	}
	

	function deleteFolder($folder){
		
		$return = false;
		
		if(is_dir($folder) && ($dir = @opendir($folder))){
			
			$return = true;
			
			while(false !== ($file = readdir($dir))){
				if($file!='.' && $file!='..'){
					
					if(is_dir($folder.'/'.$file)){
						
						if(!deleteFolder($folder.'/'.$file)){
							$return = false;
						}
						
					}else{
						
						if(!unlink($folder.'/'.$file)){
							$return = false;
						}
						
					}
					
				}
			}
			
			if($return){
				rmdir($folder);
			}
			
		}
		
		return $return;
		
	}
	

	function copyFolder($folder, $destination){
		
		$return = false;
		
		if(is_dir($folder) && !is_dir($destination) && mkdir($destination) && ($dir = @opendir($folder))){
			
			$return = true;
			
			while(false !== ($file = readdir($dir))){
				if($file!='.' && $file!='..'){
					
					if(is_dir($folder.'/'.$file)){
						
						if(!copyFolder($folder.'/'.$file, $destination.'/'.$file)){
							$return = false;
						}
						
					}else{
						
						if(!copy($folder.'/'.$file, $destination.'/'.$file)){
							$return = false;
						}
						
					}
					
				}
			}
			
		}
		
		return $return;
		
	}
	
	
	function getFilesList($folder, $array=array()){
		
		$tmp = array($folder.'/');
			
			$dir = opendir($folder);
			
			while(($file = readdir($dir)) !== false){
				
				if($file!='.' && $file!='..'){
					
					if(is_dir($folder.'/'.$file)){
						$tmp = array_merge($tmp, getFilesList($folder.'/'.$file));
					}else{
						$tmp[] = $folder.'/'.$file;
					}
					
				}
				
			}
			
		return $tmp;
		
	}
	
	
	function checkCache(){
		
		global $cache_dir, $base_dir;
		
		if(is_dir($cache_dir)){
			
			$cache_files = getFilesList($cache_dir);
			
			foreach($cache_files as $key => $val){
				if(preg_match('/(.*)\/(.*)\.(jpg|gif|png)\/$/', $val, $r) && !file_exists(str_replace($cache_dir, $base_dir, $r[1].'/'.$r[2].'.'.$r[3]))){
					
					if(deleteFolder($r[1].'/'.$r[2].'.'.$r[3])){
						echo 'Removed! - '.$r[1].'/'.$r[2].'.'.$r[3]."\n";
					}
					
				}
			}
			
		}
		
	}
	
	
	function php_multisort($data,$keys){
		
		foreach($data as $key => $row){
			foreach($keys as $k){
				$cols[$k['key']][$key] = $row[$k['key']];
			}
		}
		
		$idkeys = array_keys($data);
		
		$i = 0;
		foreach($keys as $k){
			if($i>0){$sort.=',';}
			$sort .= '$cols['.$k['key'].']';
			if($k['sort']){$sort .= ',SORT_'.strtoupper($k['sort']);}
			if($k['type']){$sort .= ',SORT_'.strtoupper($k['type']);}
			$i++;
		}
		
		$sort .= ',$idkeys';
		
		eval('array_multisort('.$sort.');');
		
		foreach($idkeys as $idkey){
			$result[$idkey] = $data[$idkey];
		}
		
		return $result;
		
	} 


?>